@@ -20,6 +20,7 @@ from .featurewiz import FE_create_categorical_feature_crosses, EDA_find_skewed_v
 from .featurewiz import FE_kmeans_resampler, FE_find_and_cap_outliers, EDA_find_outliers
 from .featurewiz import split_data_n_ways, FE_concatenate_multiple_columns
 from .featurewiz import simple_XGBoost_model, FE_discretize_numeric_variables, data_transform
+from .featurewiz import simple_lightgbm_model
 from .featurewiz import FE_transform_numeric_columns, FE_create_interaction_vars
 from .stacking_models import Stacking_Classifier, Blending_Regressor
 from .featurewiz import EDA_binning_numeric_column_displaying_bins, FE_add_lagged_targets_by_date_category
@@ -31,7 +32,7 @@ if __name__ == "__main__":
 else:
     module_type = 'Imported'
 version_number = __version__
-print("""%s featurewiz with Dask. Restart kernel after installation. Version=%s
+print("""%s DASK version = %s. Set nrows=None to sample all rows. Default is 100.
 output = featurewiz(dataname, target, corr_limit=0.70, verbose=2, sep=',', 
 		header=0, test_data='',feature_engg='', category_encoders='',
 		dask_xgboost_flag=True, nrows=None)
